@@ -15,12 +15,19 @@ module PuppetSpec::Compiler
   end
 
   def apply_compiled_manifest(manifest, prioritizer = Puppet::Graph::SequentialPrioritizer.new)
+    args = []
+    if Puppet.version.to_f < 5.0
+      args << 'apply'
+      # rubocop:disable RSpec/AnyInstance
+      Puppet::Transaction::Persistence.any_instance.stubs(:save)
+      # rubocop:enable RSpec/AnyInstance
+    end
     catalog = compile_to_ral(manifest)
     if block_given?
       catalog.resources.each { |res| yield res }
     end
     transaction = Puppet::Transaction.new(catalog,
-                                          Puppet::Transaction::Report.new,
+                                          Puppet::Transaction::Report.new(*args),
                                           prioritizer)
     transaction.evaluate
     transaction.report.finalize_report
