@@ -238,6 +238,10 @@ generated by running puppet agent with '--genconfig'.
   not start for another half hour).
 
   'puppet agent' exits after executing this.
+  
+*  --evaltrace:
+  Logs each resource as it is being evaluated. This allows you to interactively see exactly what is being done. (This is a Puppet setting, and can go in puppet.conf. Note the special 'no-' prefix for boolean settings on the command line.)
+
 
 * --fingerprint:
   Display the current certificate or certificate signing request
@@ -291,6 +295,11 @@ generated by running puppet agent with '--genconfig'.
   Enable the most common options used for testing. These are 'onetime',
   'verbose', 'no-daemonize', 'no-usecacheonfailure', 'detailed-exitcodes',
   'no-splay', and 'show_diff'.
+  
+* --trace
+  Prints stack traces on some errors. (This is a Puppet setting, and can go in puppet.conf. Note the special 'no-' prefix for boolean settings on the command line.)
+
+
 
 * --verbose:
   Turn on verbose reporting.
