@@ -1972,10 +1972,10 @@ EOT
         require 'puppet/node'
         require 'puppet/node/facts'
         if value
-          Puppet::Resource::Catalog.indirection.cache_class = :store_configs
+          Puppet::Resource::Catalog.indirection.set_global_setting(:cache_class, :store_configs)
           Puppet.settings.override_default(:catalog_cache_terminus, :store_configs)
-          Puppet::Node::Facts.indirection.cache_class = :store_configs
-          Puppet::Resource.indirection.terminus_class = :store_configs
+          Puppet::Node::Facts.indirection.set_global_setting(:cache_class, :store_configs)
+          Puppet::Resource.indirection.set_global_setting(:terminus_class, :store_configs)
         end
       end
     },
