@@ -17,10 +17,6 @@ Puppet::Face.define(:module, '1.0.0') do
       summary _("Whether to show dependencies as a tree view")
     end
 
-    option '--strict-semver' do
-      summary _('Whether version ranges should exclude pre-release versions')
-    end
-
     examples <<-'EOT'
       List installed modules:
 
@@ -77,7 +73,6 @@ Puppet::Face.define(:module, '1.0.0') do
 
       output = ''
 
-      environment.modules_strict_semver = !!options[:strict_semver]
       warn_unmet_dependencies(environment)
 
       environment.modulepath.each do |path|
@@ -128,10 +123,10 @@ Puppet::Face.define(:module, '1.0.0') do
       unmet_grouped.each do |type, deps|
         unless deps.empty?
           unmet_grouped[type].sort_by { |dep| dep[:name] }.each do |dep|
-            dep_name           = dep[:name].tr('/', '-')
+            dep_name           = dep[:name].gsub('/', '-')
             installed_version  = dep[:mod_details][:installed_version]
             version_constraint = dep[:version_constraint]
-            parent_name        = dep[:parent][:name].tr('/', '-')
+            parent_name        = dep[:parent][:name].gsub('/', '-')
             parent_version     = dep[:parent][:version]
 
             msg = _("'%{parent_name}' (%{parent_version}) requires '%{dependency_name}' (%{dependency_version})") % { parent_name: parent_name, parent_version: parent_version, dependency_name: dep_name, dependency_version: version_constraint }
@@ -151,7 +146,7 @@ Puppet::Face.define(:module, '1.0.0') do
     error_display_order.each do |type|
       unless @unmet_deps[type].empty?
         @unmet_deps[type].keys.sort.each do |dep|
-          name    = dep.tr('/', '-')
+          name    = dep.gsub('/', '-')
           errors  = @unmet_deps[type][dep][:errors]
           version = @unmet_deps[type][dep][:version]
 
@@ -219,7 +214,7 @@ Puppet::Face.define(:module, '1.0.0') do
           dep[:reason] == :missing
         end
         missing_deps.map do |mis_mod|
-          str = "#{colorize(:bg_red, _('UNMET DEPENDENCY'))} #{mis_mod[:name].tr('/', '-')} "
+          str = "#{colorize(:bg_red, _('UNMET DEPENDENCY'))} #{mis_mod[:name].gsub('/', '-')} "
           str << "(#{colorize(:cyan, mis_mod[:version_constraint])})"
           node[:dependencies] << { :text => str }
         end
@@ -244,7 +239,7 @@ Puppet::Face.define(:module, '1.0.0') do
   #
   def list_build_node(mod, parent, params)
     str = ''
-    str << (mod.forge_name ? mod.forge_name.tr('/', '-') : mod.name)
+    str << (mod.forge_name ? mod.forge_name.gsub('/', '-') : mod.name)
     str << ' (' + colorize(:cyan, mod.version ? "v#{mod.version}" : '???') + ')'
 
     unless File.dirname(mod.path) == params[:path]
