@@ -176,6 +176,10 @@ module Pal
       end
     end
 
+    # We need to make sure to set these back when we're done
+    previous_tasks_value = Puppet[:tasks]
+    previous_code_value = Puppet[:code]
+
     Puppet[:tasks] = false
     # After the assertions, if code_string is non nil - it has the highest precedence
     Puppet[:code] = code_string unless code_string.nil?
@@ -183,6 +187,10 @@ module Pal
     # If manifest_file is nil, the #main method will use the env configured manifest
     # to do things in the block while a Script Compiler is in effect
     main(manifest_file, facts, variables, :catalog, &block)
+  ensure
+    # Clean up after ourselves
+    Puppet[:tasks] = previous_tasks_value
+    Puppet[:code] = previous_code_value
   end
 
   # Defines the context in which to perform puppet operations (evaluation, etc)
