@@ -89,7 +89,8 @@ Puppet::Type.type(:service).provide :runit, :parent => :daemontools do
         # Work around issue #4480
         # runsvdir takes up to 5 seconds to recognize
         # the symlink created by this call to enable
-        Puppet.info "Waiting 5 seconds for runsvdir to discover service #{self.service}"
+        #TRANSLATORS 'runsvdir' is a linux service name and should not be translated
+        Puppet.info _("Waiting 5 seconds for runsvdir to discover service %{service}") % { service: self.service }
         sleep 5
     end
     sv "start", self.service
