@@ -1,10 +1,10 @@
+require 'time'
 require 'puppet/rest/route'
 require 'puppet/network/http_pool'
 require 'puppet/network/http/compression'
 
 module Puppet::Rest
   module Routes
-
     extend Puppet::Network::HTTP::Compression.module
 
     ACCEPT_ENCODING = 'gzip;q=1.0,deflate;q=0.6,identity;q=0.3'
@@ -16,9 +16,14 @@ module Puppet::Rest
                         srv_service: :ca)
     end
 
-    # Make an HTTP request to fetch the named certificate
-    # @param [String] name the name of the certificate to fetch
-    # @param [Puppet::SSL::SSLContext] ssl_context the ssl content to use when making the request
+    def self.clear
+      @ca = nil
+    end
+
+    # Make an HTTP request to fetch the named certificate.
+    #
+    # @param name [String] the name of the certificate to fetch
+    # @param ssl_context [Puppet::SSL::SSLContext] the ssl content to use when making the request
     # @raise [Puppet::Rest::ResponseError] if the response status is not OK
     # @return [String] the PEM-encoded certificate or certificate bundle
     def self.get_certificate(name, ssl_context)
@@ -41,14 +46,19 @@ module Puppet::Rest
       end
     end
 
-    # Make an HTTP request to fetch the named crl
-    # @param [String] name the crl to fetch
-    # @param [Puppet::SSL::SSLContext] ssl_context the ssl content to use when making the request
+    # Make an HTTP request to fetch the named crl.
+    #
+    # @param name [String] name of the crl to fetch
+    # @param ssl_context [Puppet::SSL::SSLContext] the ssl content to use when making the request
+    # @param if_modified_since [Time, nil] If non-nil, then only download the CRL if it has been
+    #   modified since the specified time.
     # @raise [Puppet::Rest::ResponseError] if the response status is not OK
     # @return [String] the PEM-encoded crl
-    def self.get_crls(name, ssl_context)
+    def self.get_crls(name, ssl_context, if_modified_since: nil)
       ca.with_base_url(Puppet::Network::Resolver.new) do |url|
         header = { 'Accept' => 'text/plain', 'Accept-Encoding' => ACCEPT_ENCODING }
+        header['If-Modified-Since'] = if_modified_since.httpdate if if_modified_since
+
         url.path += "certificate_revocation_list/#{name}"
 
         use_ssl = url.is_a? URI::HTTPS
@@ -66,11 +76,12 @@ module Puppet::Rest
       end
     end
 
-    # Make an HTTP request to send the named CSR
-    # @param [String] csr_pem the contents of the CSR to sent to the CA
-    # @param [String] name the name of the host whose CSR is being submitted
-    # @param [Puppet::SSL::SSLContext] ssl_context the ssl content to use when making the request
-    # @rasies [Puppet::Rest::ResponseError] if the response status is not OK
+    # Make an HTTP request to send the named CSR.
+    #
+    # @param csr_pem [String] the contents of the CSR to sent to the CA
+    # @param name [String] the name of the host whose CSR is being submitted
+    # @param ssl_context [Puppet::SSL::SSLContext] the ssl content to use when making the request
+    # @raise [Puppet::Rest::ResponseError] if the response status is not OK
     def self.put_certificate_request(csr_pem, name, ssl_context)
       ca.with_base_url(Puppet::Network::Resolver.new) do |url|
         header = { 'Accept' => 'text/plain',
@@ -91,11 +102,13 @@ module Puppet::Rest
       end
     end
 
-    # Make an HTTP request to get the named CSR
-    # @param [String] name the name of the host whose CSR is being queried
-    # @param [Puppet::SSL::SSLContext] ssl_context the ssl content to use when making the request
-    # @rasies [Puppet::Rest::ResponseError] if the response status is not OK
+    # Make an HTTP request to get the named CSR.
+    #
+    # @param name [String] the name of the host whose CSR is being queried
+    # @param ssl_context [Puppet::SSL::SSLContext] the ssl content to use when making the request
+    # @raise [Puppet::Rest::ResponseError] if the response status is not OK
     # @return [String] the PEM encoded certificate request
+    # @deprecated
     def self.get_certificate_request(name, ssl_context)
       ca.with_base_url(Puppet::Network::Resolver.new) do |url|
         header = { 'Accept' => 'text/plain', 'Accept-Encoding' => ACCEPT_ENCODING }
