@@ -35,7 +35,7 @@ module Puppet
     feature :refreshable, "The provider can restart the service.",
       :methods => [:restart]
 
-    feature :enableable, "The provider can enable and disable the service",
+    feature :enableable, "The provider can enable and disable the service.",
       :methods => [:disable, :enable, :enabled?]
 
     feature :controllable, "The provider uses a control variable."
@@ -49,9 +49,9 @@ module Puppet
 
     newproperty(:enable, :required_features => :enableable) do
       desc "Whether a service should be enabled to start at boot.
-        This property behaves quite differently depending on the platform;
+        This property behaves differently depending on the platform;
         wherever possible, it relies on local tools to enable or disable
-        a given service."
+        a given service. Default values depend on the platform."
 
       newvalue(:true, :event => :service_enabled) do
         provider.enable
@@ -75,6 +75,11 @@ module Puppet
         provider.enabled?
       end
 
+      # This only works on Windows systems.
+      newvalue(:delayed, :event => :service_delayed_start) do
+        provider.delayed_start
+      end
+
       # This only makes sense on systemd systems. Static services cannot be enabled
       # or disabled manually.
       def insync?(current)
@@ -87,15 +92,15 @@ module Puppet
       end
 
       validate do |value|
-        if value == :manual && !Puppet::Util::Platform.windows?
-          raise Puppet::Error.new(_("Setting enable to manual is only supported on Microsoft Windows."))
+        if (value == :manual || value == :delayed) && !Puppet::Util::Platform.windows?
+          raise Puppet::Error.new(_("Setting enable to %{value} is only supported on Microsoft Windows.") % { value: value.to_s} )
         end
       end
     end
 
     # Handle whether the service should actually be running right now.
     newproperty(:ensure) do
-      desc "Whether a service should be running."
+      desc "Whether a service should be running. Default values depend on the platform."
 
       newvalue(:stopped, :event => :service_stopped) do
         provider.stop
