@@ -148,7 +148,8 @@ module Util
 
   # Change the process to a different user
   def self.chuser
-    if group = Puppet[:group]
+    group = Puppet[:group]
+    if group
       begin
         Puppet::Util::SUIDManager.change_group(group, true)
       rescue => detail
@@ -161,7 +162,8 @@ module Util
       end
     end
 
-    if user = Puppet[:user]
+    user = Puppet[:user]
+    if user
       begin
         Puppet::Util::SUIDManager.change_user(user, true)
       rescue => detail
@@ -324,7 +326,8 @@ module Util
     if Puppet::Util::Platform.windows?
       path = path.gsub(/\\/, '/')
 
-      if unc = /^\/\/([^\/]+)(\/.+)/.match(path)
+      unc = /^\/\/([^\/]+)(\/.+)/.match(path)
+      if unc
         params[:host] = unc[1]
         path = unc[2]
       elsif path =~ /^[a-z]:\//i
@@ -551,7 +554,7 @@ module Util
   # preserved.  This works hard to avoid loss of any metadata, but will result
   # in an inode change for the file.
   #
-  # Arguments: `filename`, `default_mode`
+  # Arguments: `filename`, `default_mode`, `staging_location`
   #
   # The filename is the file we are going to replace.
   #
@@ -559,11 +562,14 @@ module Util
   # exist; if the file is present we copy the existing mode/owner/group values
   # across. The default_mode can be expressed as an octal integer, a numeric string (ie '0664')
   # or a symbolic file mode.
+  #
+  # The staging_location is a location to render the temporary file before
+  # moving the file to it's final location.
 
   DEFAULT_POSIX_MODE = 0644
   DEFAULT_WINDOWS_MODE = nil
 
-  def replace_file(file, default_mode, &block)
+  def replace_file(file, default_mode, staging_location: nil, validate_callback: nil, &block)
     raise Puppet::DevError, _("replace_file requires a block") unless block_given?
 
     if default_mode
@@ -581,9 +587,15 @@ module Util
     end
 
     begin
-      file     = Puppet::FileSystem.pathname(file)
+      file = Puppet::FileSystem.pathname(file)
+
       # encoding for Uniquefile is not important here because the caller writes to it as it sees fit
-      tempfile = Puppet::FileSystem::Uniquefile.new(Puppet::FileSystem.basename_string(file), Puppet::FileSystem.dir_string(file))
+      if staging_location
+        tempfile = Puppet::FileSystem::Uniquefile.new(Puppet::FileSystem.basename_string(file), staging_location)
+      else
+        tempfile = Puppet::FileSystem::Uniquefile.new(Puppet::FileSystem.basename_string(file), Puppet::FileSystem.dir_string(file))
+      end
+
 
       effective_mode =
       if !Puppet::Util::Platform.windows?
@@ -623,6 +635,10 @@ module Util
 
       tempfile.close
 
+      if validate_callback
+        validate_callback.call(tempfile.path)
+      end
+
       if Puppet::Util::Platform.windows?
         # Windows ReplaceFile needs a file to exist, so touch handles this
         if !Puppet::FileSystem.exist?(file)
