@@ -32,7 +32,8 @@ class Puppet::Util::Metric
 
   # Return a specific value
   def [](name)
-    if value = @values.find { |v| v[0] == name }
+    value = @values.find { |v| v[0] == name }
+    if value
       return value[2]
     else
       return 0
